Package: forestly
Title: Interactive Forest Plot
Version: 0.1.6
Authors@R: c(
    person("Yilong", "Zhang", role = c("aut")),
    person("Benjamin", "Wang", role = c("aut")),
    person("Yujie", "Zhao", email = "yujie.zhao@merck.com", role = c("aut", "cre")),
    person("Nan", "Xiao", role = c("ctb")),
    person("Hiroaki", "Fukuda", role = c("aut")),
    person("Yulia", "Sidi", role = c("ctb")),
    person("Xuan", "Deng", role = c("ctb")),
    person("Jeetener", "Chauhan", role = "ctb"),
    person("Li", "Ma", role = "ctb"),
    person("Chen", "Wang", role = "ctb"),
    person("Madhusudhan", "Ginnaram", role = "ctb"),
    person("Merck & Co., Inc., Rahway, NJ, USA and its affiliates", role = "cph")
    )
Description: Interactive forest plot for clinical trial safety analysis
    using 'metalite', 'reactable', 'plotly', and Analysis Data Model (ADaM)
    datasets. Includes functionality for adverse event filtering,
    incidence-based group filtering, hover-over reveals, and search and sort
    operations. The workflow allows for metadata construction, data preparation,
    output formatting, and interactive plot generation.
License: GPL (>= 3)
URL: https://merck.github.io/forestly/,
        https://github.com/Merck/forestly
BugReports: https://github.com/Merck/forestly/issues
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1)
Imports: brew, crosstalk, glue, htmltools, metalite, metalite.ae,
        reactable, reactR, ggplot2, uuid
Suggests: covr, dplyr, knitr, r2rtf, rmarkdown, patchwork, testthat (>=
        3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-27 15:45:47 UTC; zhayuji4
Author: Yilong Zhang [aut],
  Benjamin Wang [aut],
  Yujie Zhao [aut, cre],
  Nan Xiao [ctb],
  Hiroaki Fukuda [aut],
  Yulia Sidi [ctb],
  Xuan Deng [ctb],
  Jeetener Chauhan [ctb],
  Li Ma [ctb],
  Chen Wang [ctb],
  Madhusudhan Ginnaram [ctb],
  Merck & Co., Inc., Rahway, NJ, USA and its affiliates [cph]
Maintainer: Yujie Zhao <yujie.zhao@merck.com>
Repository: CRAN
Date/Publication: 2026-08-28 07:00:52 UTC
Built: R 4.5.2; ; 2026-08-28 09:05:33 UTC; unix
